(function (window) {
    window.AudioUtils = {
        int2pct: function (intval, maxint) {
            var pct = intval * 100.0 / maxint; // speaker volume int range 0 - 63
            return Math.round(pct);
        },

        pct2int: function (pct, maxint) {
            var n = pct * maxint / 100.0;
            return Math.round(n);
        }
    };
}(window));
